==> grug_test-0.0.1.tar.gz: grug_test-0.0.1/setup.py <==
import setuptools
import toml
from file_system_py import iterate_paths_in

# 
# get the data out of the toml file
# 
toml_info = toml.load("../pyproject.toml")
package_info = {**toml_info["tool"]["poetry"], **toml_info["tool"]["extra"]}

# 
# get the data out of the readme file
# 
with open("../README.md", "r") as file_handle:
    long_description = file_handle.read()

# 
# generate the project
#
print(f'''this might take a sec''')  
setuptools.setup(
    name=package_info["name"],
    version=package_info["version"],
    description=package_info["description"],
    url=package_info["url"],
    author=package_info["author"],
    author_email=package_info["author_email"],
    license=package_info["license"],
    packages=[package_info["name"]],
    package_data={
        # include all files/folders in the module (recursively)
        package_info["name"]: [
            each[len(package_info["name"])+1:]
                for each in iterate_paths_in(package_info["name"], recursively=True)
                    if not each.endswith(".pyc") and not each.endswith("/.keep") and ('/settings/' not in each) and ('/commands/' not in each) and ('/documentation/' not in each)
        ],
    },
    install_requires=[
        # examples:
        # 'aiohttp >= 3.7.4',
        # 'python-socketio >= 5.3.0',
        # 'requests == 2.26.0',
    ],
    classifiers=[
        # examples:
        # 'Development Status :: 5 - Production/Stable',
        # 'Intended Audience :: Developers',
        # 'Programming Language :: Python',
        # "Programming Language :: Python :: 3",
        # "Operating System :: OS Independent",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires='>=3.6',
)

==> grug_test-0.0.5.tar.gz: grug_test-0.0.5/setup.py <==
import setuptools
import toml
from file_system_py import iterate_paths_in

# 
# get the data out of the toml file
# 
toml_info = toml.load("../pyproject.toml")
package_info = {**toml_info["tool"]["poetry"], **toml_info["tool"]["extra"]}

# 
# get the data out of the readme file
# 
with open("../README.md", "r") as file_handle:
    long_description = file_handle.read()

# 
# generate the project
#
print(f'''this might take a sec''')  
setuptools.setup(
    name=package_info["name"],
    version=package_info["version"],
    description=package_info["description"],
    url=package_info["url"],
    author=package_info["author"],
    author_email=package_info["author_email"],
    license=package_info["license"],
    packages=[package_info["name"]],
    package_data={
        # include all files/folders in the module (recursively)
        package_info["name"]: [
            each[len(package_info["name"])+1:]
                for each in iterate_paths_in(package_info["name"], recursively=True)
                    if (
                        not each.endswith(".pyc")
                        and not each.endswith("/.keep")
                        and not each.endswith('.canonical')
                        and not each.endswith('.data')
                        and not each.endswith('.error')
                        and not each.endswith('.skip-ext')
                        and ('/settings/' not in each)
                        and ('/commands/' not in each)
                        and ('/documentation/' not in each)
                    )
        ],
    },
    install_requires=[
        # examples:
        # 'aiohttp >= 3.7.4',
        # 'python-socketio >= 5.3.0',
        # 'requests == 2.26.0',
    ],
    classifiers=[
        # examples:
        # 'Development Status :: 5 - Production/Stable',
        # 'Intended Audience :: Developers',
        # 'Programming Language :: Python',
        # "Programming Language :: Python :: 3",
        # "Operating System :: OS Independent",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires='>=3.6',
)
